@@ -128,16 +128,16 @@ class Exceptions:
 
 class CodePipelineClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html)
     """
 
     meta: ClientMeta
     exceptions: Exceptions
 
-    def acknowledge_job(self, jobId: str, nonce: str) -> AcknowledgeJobOutputTypeDef:
+    def acknowledge_job(self, *, jobId: str, nonce: str) -> AcknowledgeJobOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#acknowledge_job)
         """
 
@@ -145,13 +145,13 @@ class CodePipelineClient:
         self, *, jobId: str, nonce: str, clientToken: str
     ) -> AcknowledgeThirdPartyJobOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_third_party_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_third_party_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#acknowledge_third_party_job)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#can_paginate)
         """
 
@@ -168,15 +168,15 @@ class CodePipelineClient:
         tags: List["TagTypeDef"] = None
     ) -> CreateCustomActionTypeOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.create_custom_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.create_custom_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#create_custom_action_type)
         """
 
     def create_pipeline(
-        self, pipeline: "PipelineDeclarationTypeDef", tags: List["TagTypeDef"] = None
+        self, *, pipeline: "PipelineDeclarationTypeDef", tags: List["TagTypeDef"] = None
     ) -> CreatePipelineOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.create_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.create_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#create_pipeline)
         """
 
@@ -184,25 +184,25 @@ class CodePipelineClient:
         self, *, category: ActionCategoryType, provider: str, version: str
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.delete_custom_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.delete_custom_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#delete_custom_action_type)
         """
 
-    def delete_pipeline(self, name: str) -> None:
+    def delete_pipeline(self, *, name: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.delete_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.delete_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#delete_pipeline)
         """
 
-    def delete_webhook(self, name: str) -> Dict[str, Any]:
+    def delete_webhook(self, *, name: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.delete_webhook)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.delete_webhook)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#delete_webhook)
         """
 
-    def deregister_webhook_with_third_party(self, webhookName: str = None) -> Dict[str, Any]:
+    def deregister_webhook_with_third_party(self, *, webhookName: str = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.deregister_webhook_with_third_party)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.deregister_webhook_with_third_party)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#deregister_webhook_with_third_party)
         """
 
@@ -215,7 +215,7 @@ class CodePipelineClient:
         reason: str
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.disable_stage_transition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.disable_stage_transition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#disable_stage_transition)
         """
 
@@ -223,7 +223,7 @@ class CodePipelineClient:
         self, *, pipelineName: str, stageName: str, transitionType: StageTransitionTypeType
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.enable_stage_transition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.enable_stage_transition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#enable_stage_transition)
         """
 
@@ -235,7 +235,7 @@ class CodePipelineClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#generate_presigned_url)
         """
 
@@ -243,41 +243,41 @@ class CodePipelineClient:
         self, *, category: ActionCategoryType, owner: str, provider: str, version: str
     ) -> GetActionTypeOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.get_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.get_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_action_type)
         """
 
-    def get_job_details(self, jobId: str) -> GetJobDetailsOutputTypeDef:
+    def get_job_details(self, *, jobId: str) -> GetJobDetailsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.get_job_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.get_job_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_job_details)
         """
 
-    def get_pipeline(self, name: str, version: int = None) -> GetPipelineOutputTypeDef:
+    def get_pipeline(self, *, name: str, version: int = None) -> GetPipelineOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_pipeline)
         """
 
     def get_pipeline_execution(
-        self, pipelineName: str, pipelineExecutionId: str
+        self, *, pipelineName: str, pipelineExecutionId: str
     ) -> GetPipelineExecutionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_pipeline_execution)
         """
 
-    def get_pipeline_state(self, name: str) -> GetPipelineStateOutputTypeDef:
+    def get_pipeline_state(self, *, name: str) -> GetPipelineStateOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_pipeline_state)
         """
 
     def get_third_party_job_details(
-        self, jobId: str, clientToken: str
+        self, *, jobId: str, clientToken: str
     ) -> GetThirdPartyJobDetailsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.get_third_party_job_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.get_third_party_job_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_third_party_job_details)
         """
 
@@ -290,7 +290,7 @@ class CodePipelineClient:
         nextToken: str = None
     ) -> ListActionExecutionsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.list_action_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.list_action_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_action_executions)
         """
 
@@ -302,7 +302,7 @@ class CodePipelineClient:
         regionFilter: str = None
     ) -> ListActionTypesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.list_action_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.list_action_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_action_types)
         """
 
@@ -310,15 +310,15 @@ class CodePipelineClient:
         self, *, pipelineName: str, maxResults: int = None, nextToken: str = None
     ) -> ListPipelineExecutionsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.list_pipeline_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.list_pipeline_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_pipeline_executions)
         """
 
     def list_pipelines(
-        self, nextToken: str = None, maxResults: int = None
+        self, *, nextToken: str = None, maxResults: int = None
     ) -> ListPipelinesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.list_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.list_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_pipelines)
         """
 
@@ -326,15 +326,15 @@ class CodePipelineClient:
         self, *, resourceArn: str, nextToken: str = None, maxResults: int = None
     ) -> ListTagsForResourceOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_tags_for_resource)
         """
 
     def list_webhooks(
-        self, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = None, MaxResults: int = None
     ) -> ListWebhooksOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.list_webhooks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.list_webhooks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_webhooks)
         """
 
@@ -346,15 +346,15 @@ class CodePipelineClient:
         queryParam: Dict[str, str] = None
     ) -> PollForJobsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.poll_for_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.poll_for_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#poll_for_jobs)
         """
 
     def poll_for_third_party_jobs(
-        self, actionTypeId: "ActionTypeIdTypeDef", maxBatchSize: int = None
+        self, *, actionTypeId: "ActionTypeIdTypeDef", maxBatchSize: int = None
     ) -> PollForThirdPartyJobsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.poll_for_third_party_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.poll_for_third_party_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#poll_for_third_party_jobs)
         """
 
@@ -367,7 +367,7 @@ class CodePipelineClient:
         actionRevision: "ActionRevisionTypeDef"
     ) -> PutActionRevisionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.put_action_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.put_action_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_action_revision)
         """
 
@@ -381,13 +381,13 @@ class CodePipelineClient:
         token: str
     ) -> PutApprovalResultOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.put_approval_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.put_approval_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_approval_result)
         """
 
-    def put_job_failure_result(self, jobId: str, failureDetails: FailureDetailsTypeDef) -> None:
+    def put_job_failure_result(self, *, jobId: str, failureDetails: FailureDetailsTypeDef) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.put_job_failure_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.put_job_failure_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_job_failure_result)
         """
 
@@ -401,7 +401,7 @@ class CodePipelineClient:
         outputVariables: Dict[str, str] = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.put_job_success_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.put_job_success_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_job_success_result)
         """
 
@@ -409,7 +409,7 @@ class CodePipelineClient:
         self, *, jobId: str, clientToken: str, failureDetails: FailureDetailsTypeDef
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_failure_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_failure_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_third_party_job_failure_result)
         """
 
@@ -423,21 +423,21 @@ class CodePipelineClient:
         executionDetails: ExecutionDetailsTypeDef = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_success_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_success_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_third_party_job_success_result)
         """
 
     def put_webhook(
-        self, webhook: "WebhookDefinitionTypeDef", tags: List["TagTypeDef"] = None
+        self, *, webhook: "WebhookDefinitionTypeDef", tags: List["TagTypeDef"] = None
     ) -> PutWebhookOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.put_webhook)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.put_webhook)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_webhook)
         """
 
-    def register_webhook_with_third_party(self, webhookName: str = None) -> Dict[str, Any]:
+    def register_webhook_with_third_party(self, *, webhookName: str = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.register_webhook_with_third_party)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.register_webhook_with_third_party)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#register_webhook_with_third_party)
         """
 
@@ -450,15 +450,15 @@ class CodePipelineClient:
         retryMode: Literal["FAILED_ACTIONS"]
     ) -> RetryStageExecutionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.retry_stage_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.retry_stage_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#retry_stage_execution)
         """
 
     def start_pipeline_execution(
-        self, name: str, clientRequestToken: str = None
+        self, *, name: str, clientRequestToken: str = None
     ) -> StartPipelineExecutionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.start_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.start_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#start_pipeline_execution)
         """
 
@@ -471,33 +471,33 @@ class CodePipelineClient:
         reason: str = None
     ) -> StopPipelineExecutionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.stop_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.stop_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#stop_pipeline_execution)
         """
 
-    def tag_resource(self, resourceArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#tag_resource)
         """
 
-    def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#untag_resource)
         """
 
-    def update_action_type(self, actionType: "ActionTypeDeclarationTypeDef") -> None:
+    def update_action_type(self, *, actionType: "ActionTypeDeclarationTypeDef") -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.update_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.update_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#update_action_type)
         """
 
     def update_pipeline(
-        self, pipeline: "PipelineDeclarationTypeDef"
+        self, *, pipeline: "PipelineDeclarationTypeDef"
     ) -> UpdatePipelineOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Client.update_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Client.update_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#update_pipeline)
         """
 
@@ -506,7 +506,7 @@ class CodePipelineClient:
         self, operation_name: Literal["list_action_executions"]
     ) -> ListActionExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactionexecutionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactionexecutionspaginator)
         """
 
     @overload
@@ -514,7 +514,7 @@ class CodePipelineClient:
         self, operation_name: Literal["list_action_types"]
     ) -> ListActionTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactiontypespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactiontypespaginator)
         """
 
     @overload
@@ -522,13 +522,13 @@ class CodePipelineClient:
         self, operation_name: Literal["list_pipeline_executions"]
     ) -> ListPipelineExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelineexecutionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelineexecutionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelinespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelinespaginator)
         """
 
     @overload
@@ -536,11 +536,11 @@ class CodePipelineClient:
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listtagsforresourcepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listtagsforresourcepaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_webhooks"]) -> ListWebhooksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listwebhookspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listwebhookspaginator)
         """
